pub struct Array<T, const N: usize>(pub [T; N]);Expand description
An extractor to handle fixed array contexts.
This struct allows you to deserialize arrays of context types from program
entrypoint. Each element in the array is deserialized using the same
HandlerContext::from_entrypoint method, consuming accounts and instruction data
in sequence.
Type Parameters
T: The context typeN: The compile-time constant size of the array
Tuple Fields
0: [T; N]Trait Implementations
Sourceimpl<'a, 'b, 'c, T, const N: usize> HandlerContext<'a, 'b, 'c> for Array<T, N>where
T: HandlerContext<'a, 'b, 'c> + Context,
impl<'a, 'b, 'c, T, const N: usize> HandlerContext<'a, 'b, 'c> for Array<T, N>where
T: HandlerContext<'a, 'b, 'c> + Context,
fn from_entrypoint( program_id: &'a Address, accounts: &mut &'b [AccountView], instruction_data: &mut &'c [u8], ) -> Result<Self, Error>