Array

Struct Array 

pub struct Array<T, const N: usize>(pub [T; N]);
An extractor to handle fixed array contexts.

This struct allows you to deserialize arrays of context types from program entrypoint. Each element in the array is deserialized using the same HandlerContext::from_entrypoint method, consuming accounts and instruction data in sequence.

Type Parameters

  • T: The context type
  • N: The compile-time constant size of the array

Tuple Fields

0: [T; N]